"use strict";
const multer = require('multer');

const MIME_TYPE_MAP: any = {
    'image/png': 'png',
    'image/jpeg': 'jpeg',
    'image/jpg': 'jpg',
    'image/gif': 'gif',
    'image/webp': 'webp',
    'text/csv': 'csv',
    'application/pdf': 'pdf',
    'text/plain': 'txt',
    'audio/mpeg': 'mp3',
    'video/mp4': 'mp4',
    'application/vnd.ms-excel': 'xls',
    'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet': 'xlsx',
    'application/vnd.openxmlformats-officedocument.wordprocessingml.document': 'docx'
};

const storage = multer.diskStorage({
    destination: (req: any, file: any, cb: any) => {
        const isValid = MIME_TYPE_MAP[file.mimetype];
       let error: any="";
        if (!isValid) {
            error = new Error("Invalid file type");
        }
        cb(error, "uploads");
    },
    filename: (req: any, file: any, cb: any) => {
        const name = file.originalname.toLowerCase().split(' ').join('_');
        const ext = MIME_TYPE_MAP[file.mimetype];
        cb(null,   Date.now() + '-' + name);
    }
});
module.exports = multer({ storage: storage }).single('profile_pic');